DO NOT REPLY [Bug 50679] New: FarmDeployer doesn't support parallel deployment

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50679

   Summary: FarmDeployer doesn't support parallel deployment
   Product: Tomcat 7
   Version: 7.0.6
  Platform: PC
Status: NEW
  Severity: normal
  Priority: P2
 Component: Catalina
AssignedTo: dev@tomcat.apache.org
ReportedBy: jan.ru...@googlemail.com


Version: Tomcat 7.0.6
Component: Catalina
OS: Windows 7 64bit

Overview:

Parallel deployment works like a charm in a non-clustered environment. But when
deploying a versioned app (APPNAME##VERSION.war) to a farm deployer directory,
it seems that the filename encoding of the ## delimiter is not translated
correctly to identify the war file on the file system:

## is translated to %23%23

Reproduce:

1. Create a version app file
2. Deploy file to watched farm deployer directory

Expected result:
- Versioned app is copyied to cluster members and deployed

Actual result:
- Versioned app is NOT copyied to cluster members.

catalina.log displays the following error messages:


[ContainerBackgroundProcessor[StandardEngine[Catalina]]] INFO 
org.apache.catalina.ha.deploy.FarmWarDeployer- Installing
webapp[/Shop##201101261] from
C:\Apache\Tomcat7\cluster\webapps\Shop##201101261.war

[ContainerBackgroundProcessor[StandardEngine[Catalina]]] INFO 
org.apache.catalina.ha.deploy.FarmWarDeployer- Cluster wide remove of web app
/Shop##201101261

[ContainerBackgroundProcessor[StandardEngine[Catalina]]] ERROR
org.apache.catalina.ha.deploy.FarmWarDeployer- Unable to install WAR file
java.io.FileNotFoundException:
C:\Apache\Tomcat7\cluster\webapps\Shop%23%23201101261.war (Das System kann die
angegebene Datei nicht finden)
at java.io.FileInputStream.open(Native Method)
at java.io.FileInputStream.(FileInputStream.java:106)
at
org.apache.catalina.ha.deploy.FileMessageFactory.(FileMessageFactory.java:152)
at
org.apache.catalina.ha.deploy.FileMessageFactory.getInstance(FileMessageFactory.java:175)
at
org.apache.catalina.ha.deploy.FarmWarDeployer.install(FarmWarDeployer.java:372)
at
org.apache.catalina.ha.deploy.FarmWarDeployer.fileModified(FarmWarDeployer.java:468)
at org.apache.catalina.ha.deploy.WarWatcher.check(WarWatcher.java:95)
at
org.apache.catalina.ha.deploy.FarmWarDeployer.backgroundProcess(FarmWarDeployer.java:591)
at
org.apache.catalina.ha.tcp.SimpleTcpCluster.backgroundProcess(SimpleTcpCluster.java:627)
at
org.apache.catalina.core.ContainerBase.backgroundProcess(ContainerBase.java:1200)
at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.processChildren(ContainerBase.java:1393)
at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.processChildren(ContainerBase.java:1403)
at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.run(ContainerBase.java:1382)
at java.lang.Thread.run(Thread.java:662)

[ContainerBackgroundProcessor[StandardEngine[Catalina]]] INFO 
org.apache.catalina.startup.HostConfig- Deploying web application archive
Shop##201101261.war

Relevant configuration in server.xml:

...
  

 




  
  

  

  
  
  
  









  


 

  
...

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50667] Tribes | RpcChannel | Add a callback for cases when an error occured sending a reply to an RP call

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50667

--- Comment #7 from Olivier Costet  2011-01-28 04:40:39 
EST ---
(In reply to comment #5)
> Hi Olivier, yes, I see the use case. I do have a different suggestion for the
> solution, as there is a significant change. 
> I'm attaching  a patch with the summary of
> 
> 1. Not breaking the existing interfaces
> 2. Adding better feedback on a failure, and let the replying code decide 
> course
> of action
> 3. feedback on success/completion of a reply
> 
> Ability to handle async message sending.

Excellent! And yes, I also think it's better not to modify the existing
interface.

Thanks a lot, Filip, for this and for your work in general.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50634] Running a precompiled JSP causes ClassNotFoundException for dependent Jasper class

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50634

--- Comment #2 from Mark Thomas  2011-01-28 05:31:20 EST ---
I've tested this with the latest 7.0.x source. I can't reproduce the
ClassNotFoundException. That looks like compilation was done with a very old
version of JspC.

Outputting ${num} is a bug. Not sure yet what the cause is.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50634] Running a precompiled JSP causes ClassNotFoundException for dependent Jasper class

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50634

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||INVALID

--- Comment #3 from Mark Thomas  2011-01-28 05:46:52 EST ---
Further testing shows outputting ${num} is not a bug.

I suspect the web application you pre-compiled with JspC did not have a
web.xml. In this case, Tomcat assumes JSP < 2.0 where EL is not supported.
Hence ${num} gets treated as literal text.

Add a web.xml with an appropriate specification version and the JSP will work
as intended.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Tomcat 5.5.32 Build

2011-01-28 Thread Rainer Jung

On 22.01.2011 19:01, Jim Jagielski wrote:

The builds for Tomcat 5.5.32 are ready for testing and approval.
The candidates binaries are available here:

  http://people.apache.org/~jim/tomcat-5.5/

According to the release process, the 5.5.32 build corresponding to the
tag TOMCAT_5_5_32 [1] is:

[ ] Broken
[ ] Alpha
[ ] Beta
[X] Stable


- MD5 OK
- signatures OK
- key in KEYS file
- gz and zip for src and bin consistent
- src consistent with svn tag
- builds fine
- build result looks consistent with binaries

- Minor things:

  - bin/version.sh doesn_t have execute permissions in bin tarball

  - additional build.xml included in top-level src tar and zip
which is a duplicate of the one in the build directory.

  - STATUS.txt in svn, but not in src tar and zip
(I guess that's expected)

  - 4 errors in run-tester, but I vaguely remember those are
not regressions (details see below)

  - Some javadoc warnings but AFAIK TC 5.5 was never 100% clean
w.r.t. javadoc.


Details for run-tester:

   [tester] FAIL [GET /tester/ErrorPage08?type=Arithmetic HTTP/1.0] 
Expected data 'ErrorPage06 PASSED - SERVLET', got data 'ErrorPage06 
FAILED - message is not correct'
   [tester] FAIL [GET /tester/WrappedErrorPage08?type=Arithmetic 
HTTP/1.0] Expected data 'ErrorPage06 PASSED - SERVLET', got data 
'ErrorPage06 FAILED - message is not correct'
   [tester] FAIL [GET /tester/ErrorPage08?type=Array HTTP/1.0] Expected 
data 'ErrorPage06 PASSED - JSP', got data 'ErrorPage06 FAILED - message 
is not correct'
   [tester] FAIL [GET /tester/WrappedErrorPage08?type=Array HTTP/1.0] 
Expected data 'ErrorPage06 PASSED - JSP', got data 'ErrorPage06 FAILED - 
message is not correct'


Excerpt from catalina.out just in case it helps:

Jan 27, 2011 12:00:43 PM org.apache.catalina.core.ApplicationContext log
INFO: RequestListener01: requestInitialized()
Jan 27, 2011 12:00:43 PM org.apache.catalina.core.ApplicationContext log
INFO: RequestListener01: 
attributeAdded(org.apache.catalina.jsp_file,/ErrorPage08.jsp)

Jan 27, 2011 12:00:43 PM org.apache.catalina.core.ApplicationContext log
INFO: SessionListener01: sessionCreated(F404B825FBC270339EBB36A0E2303A50)
Jan 27, 2011 12:00:43 PM org.apache.catalina.core.ApplicationContext log
INFO: RequestListener01: 
attributeRemoved(org.apache.catalina.jsp_file,/ErrorPage08.jsp)
Jan 27, 2011 12:00:43 PM org.apache.catalina.core.StandardWrapperValve 
invoke

SEVERE: Servlet.service() for servlet ErrorPage08 threw exception
java.lang.ArithmeticException: ErrorPage08 Threw ArithmeticException
»···at 
org.apache.jsp.ErrorPage08_jsp._jspService(ErrorPage08_jsp.java:50)
»···at 
org.apache.jasper.runtime.HttpJspBase.service(HttpJspBase.java:98)

»···at javax.servlet.http.HttpServlet.service(HttpServlet.java:729)
»···at 
org.apache.jasper.servlet.JspServletWrapper.service(JspServletWrapper.java:369)
»···at 
org.apache.jasper.servlet.JspServlet.serviceJspFile(JspServlet.java:308)

»···at org.apache.jasper.servlet.JspServlet.service(JspServlet.java:259)
»···at javax.servlet.http.HttpServlet.service(HttpServlet.java:729)
»···at 
org.apache.catalina.core.ApplicationFilterChain.internalDoFilter(ApplicationFilterChain.java:269)
»···at 
org.apache.catalina.core.ApplicationFilterChain.doFilter(ApplicationFilterChain.java:188)

»···at org.apache.tester.StaticFilter.doFilter(StaticFilter.java:72)
»···at 
org.apache.catalina.core.ApplicationFilterChain.internalDoFilter(ApplicationFilterChain.java:215)
»···at 
org.apache.catalina.core.ApplicationFilterChain.doFilter(ApplicationFilterChain.java:188)
»···at 
org.apache.catalina.core.StandardWrapperValve.invoke(StandardWrapperValve.java:213)
»···at 
org.apache.catalina.core.StandardContextValve.invoke(StandardContextValve.java:172)
»···at 
org.apache.catalina.authenticator.AuthenticatorBase.invoke(AuthenticatorBase.java:470)
»···at 
org.apache.catalina.core.StandardHostValve.invoke(StandardHostValve.java:127)
»···at 
org.apache.catalina.valves.ErrorReportValve.invoke(ErrorReportValve.java:117)
»···at 
org.apache.catalina.core.StandardEngineValve.invoke(StandardEngineValve.java:108)
»···at 
org.apache.catalina.connector.CoyoteAdapter.service(CoyoteAdapter.java:174)
»···at 
org.apache.coyote.http11.Http11Processor.process(Http11Processor.java:879)
»···at 
org.apache.coyote.http11.Http11BaseProtocol$Http11ConnectionHandler.processConnection(Http11BaseProtocol.java:665)
»···at 
org.apache.tomcat.util.net.PoolTcpEndpoint.processSocket(PoolTcpEndpoint.java:528)
»···at 
org.apache.tomcat.util.net.LeaderFollowerWorkerThread.runIt(LeaderFollowerWorkerThread.java:81)
»···at 
org.apache.tomcat.util.threads.ThreadPool$ControlRunnable.run(ThreadPool.java:689)

»···at java.lang.Thread.run(Thread.java:534)
Jan 27, 2011 12:00:43 PM org.apache.catalina.core.ApplicationContext log
INFO: RequestListener01: 
attributeAdded(javax.servlet.error.exception,org.apache.jasper.JasperEx

Re: [VOTE] Release build 6.0.31

2011-01-28 Thread Rainer Jung

On 27.01.2011 21:39, Konstantin Kolinko wrote:

2011/1/27 jean-frederic clere:

On 01/27/2011 10:30 AM, Konstantin Kolinko wrote:


2011/1/25 jean-frederic clere:


The candidates binaries are available here:
http://people.apache.org/~jfclere/tomcat-6/v6.0.31/

According to the release process, the 6.0.31 build corresponding to the
tag TOMCAT_6_0_31 is:



[x] Beta


That is because of issue observed with Nio connector.
https://issues.apache.org/bugzilla/show_bug.cgi?id=50651

I am not saying "broken", because other connectors run OK for me.
Though, as 6.0.31 goal was to resolve regression with Nio it does not
quite serve that purpose.

The above mentioned issue is present in 6.0.30 as well.


Ok then we should go for a 6.0.32 once it is solved.



Regarding the status for 6.0.32:

1. The fix for the above mentioned regression has been applied.
2. Of the currently open issues the following one is of concern:
https://issues.apache.org/bugzilla/show_bug.cgi?id=50631
InternalNioInputBuffer should honor maxHttpHeadSize
It affects 6.0 and 7.0.


So if fixing NIO is close, should we really release 6.0.31 shortly after 
the NIO broken 6.0.30 just to release 6.0.32 shortly after? If it 
doesn't take more than say 2-3 weeks to release 6.0.32, I would suggest 
we skip 6.0.31. The reason for 6.0.31 was fixing a NIO regression, so 
IMHO we shouldn't release it if it contains another serious NIO issue 
already known.


Regards,

Rainer

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release build 6.0.31

2011-01-28 Thread Konstantin Kolinko
2011/1/28 Rainer Jung :
> On 27.01.2011 21:39, Konstantin Kolinko wrote:
>>
>> 2011/1/27 jean-frederic clere:
>>>
>>> On 01/27/2011 10:30 AM, Konstantin Kolinko wrote:

 2011/1/25 jean-frederic clere:
>
> The candidates binaries are available here:
> http://people.apache.org/~jfclere/tomcat-6/v6.0.31/
>
> According to the release process, the 6.0.31 build corresponding to the
> tag TOMCAT_6_0_31 is:

> [x] Beta

 That is because of issue observed with Nio connector.
 https://issues.apache.org/bugzilla/show_bug.cgi?id=50651

 I am not saying "broken", because other connectors run OK for me.
 Though, as 6.0.31 goal was to resolve regression with Nio it does not
 quite serve that purpose.

 The above mentioned issue is present in 6.0.30 as well.
>>>
>>> Ok then we should go for a 6.0.32 once it is solved.
>>>
>>
>> Regarding the status for 6.0.32:
>>
>> 1. The fix for the above mentioned regression has been applied.
>> 2. Of the currently open issues the following one is of concern:
>> https://issues.apache.org/bugzilla/show_bug.cgi?id=50631
>> InternalNioInputBuffer should honor maxHttpHeadSize
>> It affects 6.0 and 7.0.
>
> So if fixing NIO is close, should we really release 6.0.31 shortly after the
> NIO broken 6.0.30 just to release 6.0.32 shortly after? If it doesn't take
> more than say 2-3 weeks to release 6.0.32, I would suggest we skip 6.0.31.
> The reason for 6.0.31 was fixing a NIO regression, so IMHO we shouldn't
> release it if it contains another serious NIO issue already known.
>

Looking at  https://issues.apache.org/bugzilla/show_bug.cgi?id=50651
once again, I would say



> Regards,
>
> Rainer
>
> -
> To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
> For additional commands, e-mail: dev-h...@tomcat.apache.org
>
>

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release build 6.0.31

2011-01-28 Thread Konstantin Kolinko
2011/1/28 Konstantin Kolinko :
> 2011/1/28 Rainer Jung :
>> On 27.01.2011 21:39, Konstantin Kolinko wrote:
>>>
>>> 2011/1/27 jean-frederic clere:

 On 01/27/2011 10:30 AM, Konstantin Kolinko wrote:
>
> 2011/1/25 jean-frederic clere:
>>
>> The candidates binaries are available here:
>> http://people.apache.org/~jfclere/tomcat-6/v6.0.31/
>>
>> According to the release process, the 6.0.31 build corresponding to the
>> tag TOMCAT_6_0_31 is:
>
>> [x] Beta
>
> That is because of issue observed with Nio connector.
> https://issues.apache.org/bugzilla/show_bug.cgi?id=50651
>
> I am not saying "broken", because other connectors run OK for me.
> Though, as 6.0.31 goal was to resolve regression with Nio it does not
> quite serve that purpose.
>
> The above mentioned issue is present in 6.0.30 as well.

 Ok then we should go for a 6.0.32 once it is solved.

>>>
>>> Regarding the status for 6.0.32:
>>>
>>> 1. The fix for the above mentioned regression has been applied.
>>> 2. Of the currently open issues the following one is of concern:
>>> https://issues.apache.org/bugzilla/show_bug.cgi?id=50631
>>> InternalNioInputBuffer should honor maxHttpHeadSize
>>> It affects 6.0 and 7.0.
>>
>> So if fixing NIO is close, should we really release 6.0.31 shortly after the
>> NIO broken 6.0.30 just to release 6.0.32 shortly after? If it doesn't take
>> more than say 2-3 weeks to release 6.0.32, I would suggest we skip 6.0.31.
>> The reason for 6.0.31 was fixing a NIO regression, so IMHO we shouldn't
>> release it if it contains another serious NIO issue already known.
>>
>
> Looking at  https://issues.apache.org/bugzilla/show_bug.cgi?id=50651
> once again, I would say
that the only consequence of that issue is flooding the logs. It happens
when recycling the buffer for the second time. So, the recycle has already
successfully happened once.

Thus while 6.0.30 was not usable because of OOM in Nio,
6.0.31 is usable though has an inconvenience.


I think that it is better to release 6.0.31 (so that it were available
for download).  There is some motto "release often".

When we can go for 6.0.32/6.0.33? The code itself is stable as it is now.

I am not sure of being able to quickly fix BZ 50631 - I have an idea,
but I am not sure of consequences - it might destabilize things.

Have anyone run TCK?

Best regards,
Konstantin Kolinko

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064632 - /tomcat/tc5.5.x/trunk/STATUS.txt

2011-01-28 Thread rjung
Author: rjung
Date: Fri Jan 28 11:44:38 2011
New Revision: 1064632

URL: http://svn.apache.org/viewvc?rev=1064632&view=rev
Log:
Add proposal.

Modified:
tomcat/tc5.5.x/trunk/STATUS.txt

Modified: tomcat/tc5.5.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/STATUS.txt?rev=1064632&r1=1064631&r2=1064632&view=diff
==
--- tomcat/tc5.5.x/trunk/STATUS.txt (original)
+++ tomcat/tc5.5.x/trunk/STATUS.txt Fri Jan 28 11:44:38 2011
@@ -84,3 +84,7 @@ PATCHES PROPOSED TO BACKPORT:
   (For convenience, here is patch that applies the above:
http://people.apache.org/~kkolinko/patches/2011-01-22_tc55_50620.patch
   )
+
+* Fix permissions of version.sh in bin tarball
+  Also reorder sh file list to make completeness check more easy.
+  http://people.apache.org/~rjung/patches/fix-perms-version_sh.patch



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064634 - /tomcat/tc5.5.x/trunk/STATUS.txt

2011-01-28 Thread kkolinko
Author: kkolinko
Date: Fri Jan 28 11:56:37 2011
New Revision: 1064634

URL: http://svn.apache.org/viewvc?rev=1064634&view=rev
Log:
vote

Modified:
tomcat/tc5.5.x/trunk/STATUS.txt

Modified: tomcat/tc5.5.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc5.5.x/trunk/STATUS.txt?rev=1064634&r1=1064633&r2=1064634&view=diff
==
--- tomcat/tc5.5.x/trunk/STATUS.txt (original)
+++ tomcat/tc5.5.x/trunk/STATUS.txt Fri Jan 28 11:56:37 2011
@@ -88,3 +88,6 @@ PATCHES PROPOSED TO BACKPORT:
 * Fix permissions of version.sh in bin tarball
   Also reorder sh file list to make completeness check more easy.
   http://people.apache.org/~rjung/patches/fix-perms-version_sh.patch
+  (by rjung)
+  +1: kkolinko
+  -1:



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064652 - in /tomcat/trunk: java/org/apache/catalina/core/ java/org/apache/catalina/loader/ webapps/docs/ webapps/docs/config/

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 13:03:57 2011
New Revision: 1064652

URL: http://svn.apache.org/viewvc?rev=1064652&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=50642
Better fix for HttpClient keep-alive thread triggered memory leaks

Modified:

tomcat/trunk/java/org/apache/catalina/core/JreMemoryLeakPreventionListener.java
tomcat/trunk/java/org/apache/catalina/core/StandardContext.java
tomcat/trunk/java/org/apache/catalina/loader/LocalStrings.properties
tomcat/trunk/java/org/apache/catalina/loader/WebappClassLoader.java
tomcat/trunk/java/org/apache/catalina/loader/WebappLoader.java
tomcat/trunk/webapps/docs/changelog.xml
tomcat/trunk/webapps/docs/config/context.xml
tomcat/trunk/webapps/docs/config/listeners.xml

Modified: 
tomcat/trunk/java/org/apache/catalina/core/JreMemoryLeakPreventionListener.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/core/JreMemoryLeakPreventionListener.java?rev=1064652&r1=1064651&r2=1064652&view=diff
==
--- 
tomcat/trunk/java/org/apache/catalina/core/JreMemoryLeakPreventionListener.java 
(original)
+++ 
tomcat/trunk/java/org/apache/catalina/core/JreMemoryLeakPreventionListener.java 
Fri Jan 28 13:03:57 2011
@@ -82,19 +82,6 @@ public class JreMemoryLeakPreventionList
 
  /**
   * Protect against the memory leak caused when the first call to
-  * sun.net.www.http.HttpClient is triggered by a web
-  * application. This first call will start a KeepAlive thread with the
-  * thread's context class loader configured to be the web application 
class
-  * loader. Defaults to true.
-  */
- private boolean keepAliveProtection = true;
- public boolean isKeepAliveProtection() { return keepAliveProtection; }
- public void setKeepAliveProtection(boolean keepAliveProtection) {
- this.keepAliveProtection = keepAliveProtection;
- }
-
- /**
-  * Protect against the memory leak caused when the first call to
   * javax.security.auth.Policy is triggered by a web
   * application. This first call populate a static variable with a 
reference
   * to the context class loader. Defaults to true.
@@ -252,27 +239,6 @@ public class JreMemoryLeakPreventionList
 }
 
 /*
- * When a servlet opens a connection using a URL it will use
- * sun.net.www.http.HttpClient which keeps a static reference 
to
- * a keep-alive cache which is loaded using the web application
- * class loader.
- */
-if (keepAliveProtection) {
-try {
-Class.forName("sun.net.www.http.HttpClient");
-} catch (ClassNotFoundException e) {
-if (System.getProperty("java.vendor").startsWith(
-"Sun")) {
-log.error(sm.getString(
-"jreLeakListener.keepAliveFail"), e);
-} else {
-log.debug(sm.getString(
-"jreLeakListener.keepAliveFail"), e);
-}
-}
-}
-
-/*
  * Calling getPolicy retains a static reference to the context 
  * class loader.
  */

Modified: tomcat/trunk/java/org/apache/catalina/core/StandardContext.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/core/StandardContext.java?rev=1064652&r1=1064651&r2=1064652&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/core/StandardContext.java (original)
+++ tomcat/trunk/java/org/apache/catalina/core/StandardContext.java Fri Jan 28 
13:03:57 2011
@@ -801,6 +801,16 @@ public class StandardContext extends Con
 private boolean clearReferencesStopTimerThreads = false;
 
 /**
+ * If an HttpClient keep-alive timer thread has been started by this web
+ * application and is still running, should Tomcat change the context class
+ * loader from the current {@link WebappClassLoader} to
+ * {@link WebappClassLoader#parent} to prevent a memory leak? Note that the
+ * keep-alive timer thread will stop on its own once the keep-alives all
+ * expire however, on a busy system that might not happen for some time.
+ */
+private boolean clearReferencesHttpClientKeepAliveThread = true;
+
+/**
  * Should Tomcat renew the threads of the thread pool when the application
  * is stopped to avoid memory leaks because of uncleaned ThreadLocal
  * variables. This also requires that the threadRenewalDelay property of 
the
@@ -2535,6 +2545,28 @@ public class StandardContext extends Con
 }
 
 
+/**
+

svn commit: r1064653 - /tomcat/tc6.0.x/trunk/STATUS.txt

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 13:05:41 2011
New Revision: 1064653

URL: http://svn.apache.org/viewvc?rev=1064653&view=rev
Log:
Proposal

Modified:
tomcat/tc6.0.x/trunk/STATUS.txt

Modified: tomcat/tc6.0.x/trunk/STATUS.txt
URL: 
http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/STATUS.txt?rev=1064653&r1=1064652&r2=1064653&view=diff
==
--- tomcat/tc6.0.x/trunk/STATUS.txt (original)
+++ tomcat/tc6.0.x/trunk/STATUS.txt Fri Jan 28 13:05:41 2011
@@ -100,3 +100,9 @@ PATCHES PROPOSED TO BACKPORT:
   (kkolinko: not tested, thus not voting yet)
   +1:
   -1:
+
+* Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=50642
+  Better memory leak protection for HttpClient keep-alive thread
+  http://svn.apache.org/viewvc?rev=1064652&view=rev
+  +1: markt
+  -1:



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50642] keepAliveProtection doesn't work

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50642

Mark Thomas  changed:

   What|Removed |Added

  Component|Catalina|Catalina
Version|7.0.4   |6.0.30
Product|Tomcat 7|Tomcat 6
   Target Milestone|--- |default

--- Comment #6 from Mark Thomas  2011-01-28 08:06:21 EST ---
Grr. Eclipse hides system threads by default - hence my failure to re-create
this.

Anyway

Fixed in 7.0.x and will be included in 7.0.7 onwards.

Proposed for 6.0.x

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50677] Allow system property variables in catalina.properties

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50677

--- Comment #3 from Mark Thomas  2011-01-28 08:32:57 EST ---
I'd prefer B and I agree some care is needed with the substitution algorithm.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [VOTE] Release Tomcat 5.5.32 Build

2011-01-28 Thread Jim Jagielski

On Jan 28, 2011, at 5:56 AM, Rainer Jung wrote:
> 
>  - 4 errors in run-tester, but I vaguely remember those are
>not regressions (details see below)
> 

+1... non regressions (I should have noted them when
I called for the vote).


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50680] New: NPE in TagFileProcessor when tag file is in an expanded directory "jar"

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50680

   Summary: NPE in TagFileProcessor when tag file is in an
expanded directory "jar"
   Product: Tomcat 7
   Version: trunk
  Platform: All
OS/Version: All
Status: NEW
  Severity: normal
  Priority: P2
 Component: Jasper
AssignedTo: dev@tomcat.apache.org
ReportedBy: larry.isa...@sas.com


Created an attachment (id=26570)
 --> (https://issues.apache.org/bugzilla/attachment.cgi?id=26570)
Patch against current trunk to add a null check to TagFileProcessor

When using VirtualDirContext, or the equivalent in the Web Tools Tomcat
support, an expanded directory can be used in place of a jar file.  In this
case, tag files in the directory's META-INF folder will result in an NPE
because the jarResource obtained from the TldLocation is null.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 48358] JSP-unloading reloaded

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=48358

--- Comment #17 from Isabel Drost  2011-01-28 10:18:07 EST 
---
Created an attachment (id=26571)
 --> (https://issues.apache.org/bugzilla/attachment.cgi?id=26571)
Trivial fix for NPE problem for problem clarification

After checking the changes made to the initial patch version I think I have
found the main reason why unloading currently does not work as expected:

In org.apache.jasper.servlet.JspServlet in line 385 you call
rctxt.addWrapper(...) which adds the jsp to the list of known jsps in the
runtime context. However, for each wrapper the pointer to the unloadHandle is
not updated before wrapper.service is called (same file, line 391).

In the org.apache.jasper.compilerJspRuntimeContext in "checkUnload" (which is
triggered periodically) you iterate over the list of jsps, calling
jsw.getUnloadHandle() in line 609. This method will return null, until
wrapper.service has been called. As a result the unload loop crashes with an
NPE in that case:

org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor 
processChildren
SCHWERWIEGEND: Exception invoking periodic operation:
java.lang.NullPointerException at
org.apache.jasper.util.FastRemovalDequeue$Entry.access$700(FastRemovalDequeue.java:250)
 at
org.apache.jasper.util.FastRemovalDequeue.remove(FastRemovalDequeue.java:173)
 at
org.apache.jasper.compiler.JspRuntimeContext.checkUnload(JspRuntimeContext.java:609)
 at
org.apache.jasper.servlet.JspServlet.periodicEvent(JspServlet.java:360)
 at
org.apache.catalina.core.StandardWrapper.backgroundProcess(StandardWrapper.java:660)
 at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.processChildren(ContainerBase.java:1393)
 at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.processChildren(ContainerBase.java:1403)
 at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.processChildren(ContainerBase.java:1403)
 at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.processChildren(ContainerBase.java:1403)
 at
org.apache.catalina.core.ContainerBase$ContainerBackgroundProcessor.run(ContainerBase.java:1382)
 at java.lang.Thread.run(Thread.java:619)


The attached patch fixed the problem for us - however neither does it solve the
root cause of the issue, nor am I certain that it works in general (e.g. there
is another call to addWrapper in TagFileProcessor). Patch is merely for
clarification than for fixing the issue.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 48358] JSP-unloading reloaded

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=48358

Isabel Drost  changed:

   What|Removed |Added

 Status|RESOLVED|REOPENED
 Resolution|FIXED   |

--- Comment #18 from Isabel Drost  2011-01-28 10:19:26 EST 
---
See comment above.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064747 - /tomcat/trunk/webapps/docs/changelog.xml

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 15:57:32 2011
New Revision: 1064747

URL: http://svn.apache.org/viewvc?rev=1064747&view=rev
Log:
Not sure which recent Comet change fixed this but one of them did.

Modified:
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1064747&r1=1064746&r2=1064747&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Fri Jan 28 15:57:32 2011
@@ -117,6 +117,10 @@
 event.close() during an END event. (markt) 
   
   
+50405: Fix occassional NPE when using NIO connector and
+Comet. (markt)
+  
+  
 Ensure correct recycling of NIO input filters when processing Comet
 events. (markt)
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50405] Null Pointer Exception at Coyote Adapter

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50405

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED

--- Comment #4 from Mark Thomas  2011-01-28 10:57:33 EST ---
Thanks for the test case. I just ran it against the latest 7.0.x and I no
longer see the NPE. I recently fixed a bunch of Comet issues with 7.0.x so I
suspect that the root cause of this got fixed as part of that.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50634] Running a precompiled JSP causes ClassNotFoundException for dependent Jasper class

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50634

--- Comment #4 from Christopher Schultz  
2011-01-28 12:40:39 EST ---
(In reply to comment #2)
> I've tested this with the latest 7.0.x source. I can't reproduce the
> ClassNotFoundException. That looks like compilation was done with a very old
> version of JspC.

I was using 7.0.x/trunk at the time. I'll re-try.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064791 - /tomcat/trunk/java/org/apache/catalina/ha/deploy/WarWatcher.java

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 17:41:45 2011
New Revision: 1064791

URL: http://svn.apache.org/viewvc?rev=1064791&view=rev
Log:
Don't need an INFO log message every 30s when the FarmWarDeployer is running

Modified:
tomcat/trunk/java/org/apache/catalina/ha/deploy/WarWatcher.java

Modified: tomcat/trunk/java/org/apache/catalina/ha/deploy/WarWatcher.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/ha/deploy/WarWatcher.java?rev=1064791&r1=1064790&r2=1064791&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/ha/deploy/WarWatcher.java (original)
+++ tomcat/trunk/java/org/apache/catalina/ha/deploy/WarWatcher.java Fri Jan 28 
17:41:45 2011
@@ -75,8 +75,8 @@ public class WarWatcher {
  * check for modification and send notification to listener
  */
 public void check() {
-if (log.isInfoEnabled())
-log.info("check cluster wars at " + watchDir);
+if (log.isDebugEnabled())
+log.debug("check cluster wars at " + watchDir);
 File[] list = watchDir.listFiles(new WarFilter());
 if (list == null)
 list = new File[0];



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50634] Running a precompiled JSP causes ClassNotFoundException for dependent Jasper class

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50634

--- Comment #5 from Christopher Schultz  
2011-01-28 12:50:35 EST ---
> Further testing shows outputting ${num} is not a bug.
> 
> I suspect the web application you pre-compiled with JspC did not have a
> web.xml. In this case, Tomcat assumes JSP < 2.0 where EL is not supported.
> Hence ${num} gets treated as literal text.

In fact, the webapp does have a web.xml using the 3.0 schema.

> Add a web.xml with an appropriate specification version and the JSP will work
> as intended.

Sure?

Does it also make sense that accessing the precompiled JSP gives me one
behavior while accessing the non-precompiled JSP gives me another?

I'll bet I know what happened:

I pre-compiled the JSPs with no web.xml, so JspC defaulted as you say to JSP
2.0 with no EL availability.

I deployed both the precompiled and source JSP into a 3.0-spec webapp, so the
precompiled version and on-the-fly version operate differently.

Lemmie double-check and I'll VERIFY INVALID.

I'm still concerned about the CNFE, though...

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064887 - in /tomcat/site/trunk: docs/migration.html xdocs/migration.xml

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 21:13:19 2011
New Revision: 1064887

URL: http://svn.apache.org/viewvc?rev=1064887&view=rev
Log:
Add some internal API notes to the migration page

Modified:
tomcat/site/trunk/docs/migration.html
tomcat/site/trunk/xdocs/migration.xml

Modified: tomcat/site/trunk/docs/migration.html
URL: 
http://svn.apache.org/viewvc/tomcat/site/trunk/docs/migration.html?rev=1064887&r1=1064886&r2=1064887&view=diff
==
--- tomcat/site/trunk/docs/migration.html (original)
+++ tomcat/site/trunk/docs/migration.html Fri Jan 28 21:13:19 2011
@@ -262,6 +262,9 @@
 
 System properties
 
+
+Internal APIs
+
 
 
 
@@ -1091,6 +1094,46 @@ compatibility problems.
 
 
 
+  
+
+
+
+
+
+
+
+Internal APIs
+
+
+
+
+
+
+
+  
+Whilst the Tomcat 7 internal API is broadly compatible with Tomcat 6
+there have been many changes at the detai level and they are not binary
+compatible. Developers of custom components that interact with Tomcat's
+internals should review the JavaDoc for the relevant API. Of particular 
note
+are:
+
+  Use of generics.
+  A standard implementation of the Lifecycle interface that all
+  components extend.
+  The use of Context name rather than Context path as the unique
+  identifier for a Context within a Host.
+
+
+  
+
+
+
+
+
+
+
+
+
 
 
 

Modified: tomcat/site/trunk/xdocs/migration.xml
URL: 
http://svn.apache.org/viewvc/tomcat/site/trunk/xdocs/migration.xml?rev=1064887&r1=1064886&r2=1064887&view=diff
==
--- tomcat/site/trunk/xdocs/migration.xml (original)
+++ tomcat/site/trunk/xdocs/migration.xml Fri Jan 28 21:13:19 2011
@@ -341,6 +341,23 @@ compatibility problems.
 
   
 
+  
+  
+Whilst the Tomcat 7 internal API is broadly compatible with Tomcat 6
+there have been many changes at the detai level and they are not binary
+compatible. Developers of custom components that interact with 
Tomcat's
+internals should review the JavaDoc for the relevant API. Of particular 
note
+are:
+
+  Use of generics.
+  A standard implementation of the Lifecycle interface that all
+  components extend.
+  The use of Context name rather than Context path as the unique
+  identifier for a Context within a Host.
+
+
+  
+
 
 
 



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064890 - in /tomcat/trunk: java/org/apache/jasper/compiler/TagFileProcessor.java webapps/docs/changelog.xml

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 21:21:02 2011
New Revision: 1064890

URL: http://svn.apache.org/viewvc?rev=1064890&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=50680
Prevent an NPE when using tag files from an exploded JAR file, e.g. from within 
an IDE.
Patch provided by Larry Isaacs.

Modified:
tomcat/trunk/java/org/apache/jasper/compiler/TagFileProcessor.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/jasper/compiler/TagFileProcessor.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/jasper/compiler/TagFileProcessor.java?rev=1064890&r1=1064889&r2=1064890&view=diff
==
--- tomcat/trunk/java/org/apache/jasper/compiler/TagFileProcessor.java 
(original)
+++ tomcat/trunk/java/org/apache/jasper/compiler/TagFileProcessor.java Fri Jan 
28 21:21:02 2011
@@ -626,10 +626,15 @@ class TagFileProcessor {
 compiler.getCompilationContext().getTldLocation(
 tagFileInfo.getTagInfo().getTagLibrary().getURI());
 JarResource jarResource = location.getJarResource();
-// Add TLD
-
pageInfo.addDependant(jarResource.getEntry(location.getName()).toString());
-// Add Tag
-
pageInfo.addDependant(jarResource.getEntry(tagFilePath.substring(1)).toString());
+if (jarResource != null) {
+// Add TLD
+
pageInfo.addDependant(jarResource.getEntry(location.getName()).toString());
+// Add Tag
+
pageInfo.addDependant(jarResource.getEntry(tagFilePath.substring(1)).toString());
+}
+else {
+pageInfo.addDependant(tagFilePath);
+}
 } else {
 pageInfo.addDependant(tagFilePath);
 }

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1064890&r1=1064889&r2=1064890&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Fri Jan 28 21:21:02 2011
@@ -150,6 +150,11 @@
 Improve error message when EL identifiers are not valid Java 
identifiers
 and use i18n for the error message. (markt)
   
+  
+50680: Prevent an NPE when using tag files from an exploded
+JAR file, e.g. from within an IDE. Patch provided by Larry Isaacs.
+(markt)
+  
 
   
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50680] NPE in TagFileProcessor when tag file is in an expanded directory "jar"

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50680

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED

--- Comment #1 from Mark Thomas  2011-01-28 16:21:25 EST ---
Many thanks for the patch.

I have applied it to 7.0.x and it will be in 7.0.7 onwards.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064893 - /tomcat/trunk/webapps/docs/changelog.xml

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 21:31:48 2011
New Revision: 1064893

URL: http://svn.apache.org/viewvc?rev=1064893&view=rev
Log:
Remove whitespace

Modified:
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1064893&r1=1064892&r2=1064893&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Fri Jan 28 21:31:48 2011
@@ -139,8 +139,7 @@
   
 Improve special case handling of
 javax.servlet.jsp.el.ScopedAttributeELResolver in
-javax.el.CompositeELResolver  to handle sub-classes.
-(markt)
+javax.el.CompositeELResolver to handle sub-classes. 
(markt)
   
   
 15688: Use fully-qualified class names in generated jsp 
files



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064897 - /tomcat/trunk/java/org/apache/tomcat/util/http/AcceptLanguage.java

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 21:41:02 2011
New Revision: 1064897

URL: http://svn.apache.org/viewvc?rev=1064897&view=rev
Log:
Remove unused file

Removed:
tomcat/trunk/java/org/apache/tomcat/util/http/AcceptLanguage.java


-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 38916] HttpServletRequest cannot handle multipart request quickly

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=38916

Mark Thomas  changed:

   What|Removed |Added

 Status|NEEDINFO|RESOLVED
 Resolution||WONTFIX

--- Comment #2 from Mark Thomas  2011-01-28 17:28:58 EST ---
This was fixed in r718155 for 6.0.x and 7.0.x. It wasn't back-ported to 5.5.x.

Marking this as WONTFIX for 5.5.x

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 28168] patch to add webdoclet tags to jspc output

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=28168

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||WONTFIX

--- Comment #2 from Mark Thomas  2011-01-28 17:55:58 EST ---
I don't recall any requests for this feature other than this enhancement
request so I am closing this a WONTFIX. I would add that if there were a demand
for this feature, then the addition of the webdoclet information would have to
be optional before the patch would be accepted.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 25148] JDBCRealm should get the user name from database after login and not use the string given by the user

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=25148

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||DUPLICATE

--- Comment #1 from Mark Thomas  2011-01-28 18:02:50 EST ---


*** This bug has been marked as a duplicate of bug 26494 ***

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 26494] JDBCRealm and DataSourceRealm with case insensitive user names

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=26494

--- Comment #1 from Mark Thomas  2011-01-28 18:02:51 EST ---
*** Bug 25148 has been marked as a duplicate of this bug. ***

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49978] WebappLoader throws exception if workDir already exists (when unpackWARs=false)

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49978

kristof batizy  changed:

   What|Removed |Added

 Status|RESOLVED|REOPENED
 Resolution|FIXED   |

--- Comment #2 from kristof batizy  2011-01-28 18:05:22 EST 
---
I am seeing this, or similar, on Windows XP (32 bit) 7.0.6 under the same
conditions (unpackWars=false)

SEVERE: LifecycleException
java.io.IOException: Failed to copy resources
at
org.apache.catalina.loader.WebappLoader.setRepositories(WebappLoader.java:890)
at
org.apache.catalina.loader.WebappLoader.startInternal(WebappLoader.java:601)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:145)
at
org.apache.catalina.core.StandardContext.startInternal(StandardContext.java:4857)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:145)
at
org.apache.catalina.core.ContainerBase.addChildInternal(ContainerBase.java:812)
at
org.apache.catalina.core.ContainerBase.addChild(ContainerBase.java:787)
at
org.apache.catalina.core.StandardHost.addChild(StandardHost.java:583)
at
org.apache.catalina.startup.HostConfig.deployWAR(HostConfig.java:917)
at
org.apache.catalina.startup.HostConfig.deployWARs(HostConfig.java:715)
at
org.apache.catalina.startup.HostConfig.deployApps(HostConfig.java:469)
at org.apache.catalina.startup.HostConfig.start(HostConfig.java:1294)
at
org.apache.catalina.startup.HostConfig.lifecycleEvent(HostConfig.java:310)
at
org.apache.catalina.util.LifecycleSupport.fireLifecycleEvent(LifecycleSupport.java:119)
at
org.apache.catalina.util.LifecycleBase.fireLifecycleEvent(LifecycleBase.java:89)
at
org.apache.catalina.util.LifecycleBase.setState(LifecycleBase.java:343)
at
org.apache.catalina.util.LifecycleBase.setState(LifecycleBase.java:323)
at
org.apache.catalina.core.ContainerBase.startInternal(ContainerBase.java:1043)
at
org.apache.catalina.core.StandardHost.startInternal(StandardHost.java:750)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:145)
at
org.apache.catalina.core.ContainerBase.startInternal(ContainerBase.java:1035)
at
org.apache.catalina.core.StandardEngine.startInternal(StandardEngine.java:291)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:145)
at
org.apache.catalina.core.StandardService.startInternal(StandardService.java:442)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:145)
at
org.apache.catalina.core.StandardServer.startInternal(StandardServer.java:674)
at org.apache.catalina.util.LifecycleBase.start(LifecycleBase.java:145)
at org.apache.catalina.startup.Catalina.start(Catalina.java:600)
at sun.reflect.NativeMethodAccessorImpl.invoke0(Native Method)
at
sun.reflect.NativeMethodAccessorImpl.invoke(NativeMethodAccessorImpl.java:39)
at
sun.reflect.DelegatingMethodAccessorImpl.invoke(DelegatingMethodAccessorImpl.java:25)
at java.lang.reflect.Method.invoke(Method.java:597)
at org.apache.catalina.startup.Bootstrap.start(Bootstrap.java:303)
at org.apache.catalina.startup.Bootstrap.main(Bootstrap.java:431)

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064929 - in /tomcat/trunk: java/org/apache/jasper/runtime/JspRuntimeLibrary.java webapps/docs/changelog.xml

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 23:24:23 2011
New Revision: 1064929

URL: http://svn.apache.org/viewvc?rev=1064929&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=46819
Remove redundant object instantiations in JspRuntimeLibrary.
Patch provided by Anthony Whitford.

Modified:
tomcat/trunk/java/org/apache/jasper/runtime/JspRuntimeLibrary.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/jasper/runtime/JspRuntimeLibrary.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/jasper/runtime/JspRuntimeLibrary.java?rev=1064929&r1=1064928&r2=1064929&view=diff
==
--- tomcat/trunk/java/org/apache/jasper/runtime/JspRuntimeLibrary.java 
(original)
+++ tomcat/trunk/java/org/apache/jasper/runtime/JspRuntimeLibrary.java Fri Jan 
28 23:24:23 2011
@@ -118,14 +118,14 @@ public class JspRuntimeLibrary {
 if (s == null || s.length() == 0)
 return false;
 else
-return Boolean.valueOf(s).booleanValue();
+return Boolean.parseBoolean(s);
 }
 
 public static byte coerceToByte(String s) {
 if (s == null || s.length() == 0)
 return (byte) 0;
 else
-return Byte.valueOf(s).byteValue();
+return Byte.parseByte(s);
 }
 
 public static char coerceToChar(String s) {
@@ -141,35 +141,35 @@ public class JspRuntimeLibrary {
 if (s == null || s.length() == 0)
 return 0;
 else
-return Double.valueOf(s).doubleValue();
+return Double.parseDouble(s);
 }
 
 public static float coerceToFloat(String s) {
 if (s == null || s.length() == 0)
 return 0;
 else
-return Float.valueOf(s).floatValue();
+return Float.parseFloat(s);
 }
 
 public static int coerceToInt(String s) {
 if (s == null || s.length() == 0)
 return 0;
 else
-return Integer.valueOf(s).intValue();
+return Integer.parseInt(s);
 }
 
 public static short coerceToShort(String s) {
 if (s == null || s.length() == 0)
 return (short) 0;
 else
-return Short.valueOf(s).shortValue();
+return Short.parseShort(s);
 }
 
 public static long coerceToLong(String s) {
 if (s == null || s.length() == 0)
 return 0;
 else
-return Long.valueOf(s).longValue();
+return Long.parseLong(s);
 }
 
 public static Object coerce(String s, Class target) {
@@ -183,39 +183,39 @@ public class JspRuntimeLibrary {
 return Boolean.valueOf(s);
 } else if (target == Byte.class) {
 if (isNullOrEmpty)
-return new Byte((byte) 0);
+return Byte.valueOf((byte) 0);
 else
-return new Byte(s);
+return Byte.valueOf(s);
 } else if (target == Character.class) {
 if (isNullOrEmpty)
-return new Character((char) 0);
+return Character.valueOf((char) 0);
 else 
-return new Character(s.charAt(0));
+return Character.valueOf(s.charAt(0));
 } else if (target == Double.class) {
 if (isNullOrEmpty)
-return new Double(0);
+return Double.valueOf(0);
 else
-return new Double(s);
+return Double.valueOf(s);
 } else if (target == Float.class) {
 if (isNullOrEmpty)
-return new Float(0);
+return Float.valueOf(0);
 else
-return new Float(s);
+return Float.valueOf(s);
 } else if (target == Integer.class) {
 if (isNullOrEmpty)
-return new Integer(0);
+return Integer.valueOf(0);
 else
-return new Integer(s);
+return Integer.valueOf(s);
 } else if (target == Short.class) {
 if (isNullOrEmpty)
-return new Short((short) 0);
+return Short.valueOf((short) 0);
 else
-return new Short(s);
+return Short.valueOf(s);
 } else if (target == Long.class) {
 if (isNullOrEmpty)
-return new Long(0);
+return Long.valueOf(0);
 else
-return new Long(s);
+return Long.valueOf(s);
 } else {
 return null;
 }
@@ -243,19 +243,19 @@ public class JspRuntimeLibrary {
 s = "false";
 return Boolean.valueOf(s);
 } else if ( t.equals(Byte.class) || t.equals(Byte.TYPE) ) {
-return new Byte(s);
+return Byte.valueOf(s);
 } else if (t.equals(Charact

DO NOT REPLY [Bug 46819] Remove redundant object instantiations in JspRuntimeLibrary

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=46819

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED

--- Comment #1 from Mark Thomas  2011-01-28 18:24:55 EST ---
The patch has been applied to 7.0.x and will be included in 7.0.7 onwards.

There are no plans to back-ported it to 6.0.x.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50683] New: Servlet 3.0 annotations not scanned if unpackWars="false"

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50683

   Summary: Servlet 3.0 annotations not scanned if
unpackWars="false"
   Product: Tomcat 7
   Version: 7.0.6
  Platform: PC
OS/Version: Windows XP
Status: NEW
  Severity: normal
  Priority: P2
 Component: Catalina
AssignedTo: dev@tomcat.apache.org
ReportedBy: kris...@batizy.com


Created an attachment (id=26572)
 --> (https://issues.apache.org/bugzilla/attachment.cgi?id=26572)
minimal test case war with source

Overview: 

Given a very simple HelloServlet using @WebServlet annotation, and packed in a
war file without a web.xml, the container does not scan for annotations if
unpackWars="false" in the  element of server.xml and the servlet is never
added to the context.

Steps to Reproduce: 

1) Set unpackWars="fase"

2) copy attached war file to webapps

3) launch Tomcat

4) navigate to:  http:///Hello/SayHello

Actual Results: 

  HTTP Status 404 - /Hello/SayHello

  type Status report

  message /Hello/SayHello

  description The requested resource (/Hello/SayHello) is not available.
  Apache Tomcat/7.0.6

Expected Results: 

  Hello

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50683] Servlet 3.0 annotations not scanned if unpackWars="false"

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50683

--- Comment #1 from kristof batizy  2011-01-28 18:37:39 EST 
---
sorry, typo in step 1, above:

1) Set unpackWars="false"

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 48208] allow client certificate with any issuer: server.xml connector attribute "acceptAllCerts"

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=48208

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||WONTFIX

--- Comment #1 from Mark Thomas  2011-01-28 18:39:49 EST ---
Accepting all client certificates defeats the purpose of CLIENT_CERT.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49978] WebappLoader throws exception if workDir already exists (when unpackWARs=false)

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49978

kristof batizy  changed:

   What|Removed |Added

 CC||kris...@batizy.com

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064932 - in /tomcat/trunk: java/org/apache/catalina/loader/WebappLoader.java webapps/docs/changelog.xml

2011-01-28 Thread markt
Author: markt
Date: Sat Jan 29 00:00:50 2011
New Revision: 1064932

URL: http://svn.apache.org/viewvc?rev=1064932&view=rev
Log:
Re-fix https://issues.apache.org/bugzilla/show_bug.cgi?id=49978
Pre-existing dir should not break deployment

Modified:
tomcat/trunk/java/org/apache/catalina/loader/WebappLoader.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/catalina/loader/WebappLoader.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/loader/WebappLoader.java?rev=1064932&r1=1064931&r2=1064932&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/loader/WebappLoader.java (original)
+++ tomcat/trunk/java/org/apache/catalina/loader/WebappLoader.java Sat Jan 29 
00:00:50 2011
@@ -1128,7 +1128,7 @@ public class WebappLoader extends Lifecy
 if (!copy((InputStream) object, os))
 return false;
 } else if (object instanceof DirContext) {
-if (!currentFile.mkdir())
+if (!currentFile.isDirectory() && !currentFile.mkdir())
 return false;
 if (!copyDir((DirContext) object, currentFile))
 return false;

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1064932&r1=1064931&r2=1064932&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Sat Jan 29 00:00:50 2011
@@ -72,6 +72,10 @@
 context attribute is set to "true". (schultz)
   
   
+49978: Correct another instance where deployment incorrectly
+failed if a directory in the work area already existed. (markt)
+  
+  
 50582: Refactor access logging so chunked encoding is not
 forced for all requests if bytes sent is logged. (markt)
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 49978] WebappLoader throws exception if workDir already exists (when unpackWARs=false)

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=49978

Mark Thomas  changed:

   What|Removed |Added

 Status|REOPENED|RESOLVED
 Resolution||FIXED

--- Comment #3 from Mark Thomas  2011-01-28 19:01:31 EST ---
Yep, there was another similar issue in the same area. Fixed in 7.0.x and will
be in 7.0.7 onwards.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064934 - in /tomcat/trunk: java/org/apache/naming/resources/WARDirContext.java webapps/docs/changelog.xml

2011-01-28 Thread markt
Author: markt
Date: Sat Jan 29 00:15:34 2011
New Revision: 1064934

URL: http://svn.apache.org/viewvc?rev=1064934&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=50683
Scan annotations when unpackWars=false

Modified:
tomcat/trunk/java/org/apache/naming/resources/WARDirContext.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/naming/resources/WARDirContext.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/naming/resources/WARDirContext.java?rev=1064934&r1=1064933&r2=1064934&view=diff
==
--- tomcat/trunk/java/org/apache/naming/resources/WARDirContext.java (original)
+++ tomcat/trunk/java/org/apache/naming/resources/WARDirContext.java Sat Jan 29 
00:15:34 2011
@@ -471,6 +471,8 @@ public class WARDirContext extends BaseD
 attrs.setName(entry.getName());
 if (!zipEntry.isDirectory())
 attrs.setResourceType("");
+else
+attrs.setCollection(true);
 attrs.setContentLength(zipEntry.getSize());
 attrs.setLastModified(zipEntry.getTime());
 

Modified: tomcat/trunk/webapps/docs/changelog.xml
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/webapps/docs/changelog.xml?rev=1064934&r1=1064933&r2=1064934&view=diff
==
--- tomcat/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/trunk/webapps/docs/changelog.xml Sat Jan 29 00:15:34 2011
@@ -108,6 +108,11 @@
 WebappClassLoader since the thread that triggers the memory leak is
 created on demand. (markt)
   
+  
+50683: Ensure annotations are scanned when upackWars is set
+to false in the Host where a web application is deployed.
+(markt)
+  
 
   
   



-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50683] Servlet 3.0 annotations not scanned if unpackWars="false"

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50683

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED

--- Comment #2 from Mark Thomas  2011-01-28 19:16:05 EST ---
Thanks for the report and the test case.

The issue has been fixed in 7.0.x and will be included in 7.0.7 onwards.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 50667] Tribes | RpcChannel | Add a callback for cases when an error occured sending a reply to an RP call

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50667

--- Comment #8 from Filip Hanik  2011-01-28 13:31:15 EST ---
hi Olivier, I'm still noodling (thinking) about this. I am not thrilled about
the 
if (async) else 
case here. But rest assured, a solution will come.

best
Filip

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



svn commit: r1064881 - in /tomcat/trunk: java/org/apache/catalina/ha/ java/org/apache/catalina/ha/deploy/ webapps/docs/

2011-01-28 Thread markt
Author: markt
Date: Fri Jan 28 21:04:55 2011
New Revision: 1064881

URL: http://svn.apache.org/viewvc?rev=1064881&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=50679
Update the FarmWarDeployer to support parallel deployment. This deliberately 
breaks the API since the meaning of a number of method parameters has changed 
(context path -> context name).

Modified:
tomcat/trunk/java/org/apache/catalina/ha/ClusterDeployer.java
tomcat/trunk/java/org/apache/catalina/ha/deploy/FarmWarDeployer.java
tomcat/trunk/java/org/apache/catalina/ha/deploy/FileMessage.java
tomcat/trunk/java/org/apache/catalina/ha/deploy/FileMessageFactory.java
tomcat/trunk/java/org/apache/catalina/ha/deploy/UndeployMessage.java
tomcat/trunk/webapps/docs/changelog.xml

Modified: tomcat/trunk/java/org/apache/catalina/ha/ClusterDeployer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/catalina/ha/ClusterDeployer.java?rev=1064881&r1=1064880&r2=1064881&view=diff
==
--- tomcat/trunk/java/org/apache/catalina/ha/ClusterDeployer.java (original)
+++ tomcat/trunk/java/org/apache/catalina/ha/ClusterDeployer.java Fri Jan 28 
21:04:55 2011
@@ -24,8 +24,8 @@ package org.apache.catalina.ha;
  * @author Filip Hanik
  * @version $Id$
  */
+import java.io.File;
 import java.io.IOException;
-import java.net.URL;
 
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.tribes.ChannelListener;
@@ -48,59 +48,48 @@ public interface ClusterDeployer extends
 public void stop() throws LifecycleException;
 
 /**
- * Sets the deployer for this cluster deployer to use.
- * @param deployer Deployer
- */
-// FIXME
-//public void setDeployer(Deployer deployer);
-
-/**
  * Install a new web application, whose web application archive is at the
  * specified URL, into this container and all the other
- * members of the cluster with the specified context path.
- * A context path of "" (the empty string) should be used for the root
- * application for this container.  Otherwise, the context path must
- * start with a slash.
+ * members of the cluster with the specified context name.
  * 
  * If this application is successfully installed locally, 
  * a ContainerEvent of type
  * INSTALL_EVENT will be sent to all registered listeners,
  * with the newly created Context as an argument.
  *
  * @param contextPath The context path to which this application should
  *  be installed (must be unique)
- * @param war A URL of type "jar:" that points to a WAR file, or type
- *  "file:" that points to an unpacked directory structure containing
- *  the web application to be installed
+ * @param wepappA WAR file or unpacked directory structure containing
+ *  the web application to be installed
  *
  * @exception IllegalArgumentException if the specified context path
  *  is malformed (it must be "" or start with a slash)
  * @exception IllegalStateException if the specified context path
  *  is already attached to an existing web application
  * @exception IOException if an input/output error was encountered
  *  during installation
  */
-public void install(String contextPath, URL war) throws IOException;
+public void install(String contextName, File webapp) throws IOException;
 
 /**
  * Remove an existing web application, attached to the specified context
  * path.  If this application is successfully removed, a
  * ContainerEvent of type REMOVE_EVENT will be sent to all
  * registered listeners, with the removed Context as
  * an argument. Deletes the web application war file and/or directory
  * if they exist in the Host's appBase.
  *
  * @param contextPath The context path of the application to be removed
  * @param undeploy boolean flag to remove web application from server
  *
  * @exception IllegalArgumentException if the specified context path
  *  is malformed (it must be "" or start with a slash)
  * @exception IllegalArgumentException if the specified context path does
  *  not identify a currently installed web application
  * @exception IOException if an input/output error occurs during
  *  removal
  */
-public void remo

DO NOT REPLY [Bug 50679] FarmDeployer doesn't support parallel deployment

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=50679

Mark Thomas  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution||FIXED
 OS/Version||All

--- Comment #1 from Mark Thomas  2011-01-28 16:06:19 EST ---
@@ -48,59 +48,48 @@ public interface ClusterDeployer extends
  * with the newly created Context as an argument.
  *
- * @param contextPath The context path to which this application should
+ * @param contextName The context name to which this application should
  *  be installed (must be unique)
@@ -48,59 +48,48 @@ public interface ClusterDeployer extends
  *
- * @exception IllegalArgumentException if the specified context path
- *  is malformed (it must be "" or start with a slash)
- * @exception IllegalStateException if the specified context path
+ * @exception IllegalArgumentException if the specified context name
+ *  is malformed
+ * @exception IllegalStateException if the specified context name
  *  is already attached to an existing web application
  * @exception IOException if an input/output error was encountered
@@ -48,59 +48,48 @@ public interface ClusterDeployer extends
 /**
  * Remove an existing web application, attached to the specified context
- * path.  If this application is successfully removed, a
+ * name.  If this application is successfully removed, a
  * ContainerEvent of type REMOVE_EVENT will be sent to all
  * registered listeners, with the removed Context as
@@ -48,59 +48,48 @@ public interface ClusterDeployer extends
  * if they exist in the Host's appBase.
  *
- * @param contextPath The context path of the application to be removed
+ * @param contextName The context name of the application to be removed
  * @param undeploy boolean flag to remove web application from server
  *
@@ -48,59 +48,48 @@ public interface ClusterDeployer extends
  * @param undeploy boolean flag to remove web application from server
  *
- * @exception IllegalArgumentException if the specified context path
- *  is malformed (it must be "" or start with a slash)
- * @exception IllegalArgumentException if the specified context path does
+ * @exception IllegalArgumentException if the specified context name
+ *  is malformed
+ * @exception IllegalArgumentException if the specified context name does
  *  not identify a currently installed web application
  * @exception IOException if an input/output error occurs during
Thanks for your report. Glad to hear parallel deployment is working well.

I have fixed the FarmWarDeployer in 7.0.x and the fix will be included in 7.0.7
onwards.

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



Re: [taglibs] Time to release 1.2.0?

2011-01-28 Thread Henri Yandell
On Sun, Jan 23, 2011 at 12:41 PM, Jeremy Boynes  wrote:
> The only bug remaining that impact the JSTL libraries is #46052 (locale 
> performance on 1.6). Henri suggested releasing in its current form which 
> sounds reasonable. Should we release this as 1.2.0? Is this a good version 
> number - should we use something like 1.2.0-beta?
>
> This will be the first release in a long time and the first since the switch 
> to a Maven based build. The process is described here
>        http://www.apache.org/dev/publishing-maven-artifacts.html
>
> I think we need to release the parent POM first to get it in the central 
> repo, and then the artifacts that depend on it.
>
> I'd volunteer to RM this but:
> 1) I'm not a PMC member (which I don't think matters if we get enough votes 
> from PMC members)

None of the Taglib committers are, so not an important one :)

> 2) I'd need to update my PGP key in the WoT (somehow)

Do we need new keys now? I can obviously hook you into the WoT if I'm
still in it given that we can arrange something during the day.

> 3) I've not done the above process before so will likely mess things up.

Me neither. Best foot forward etc :)

+1

Hen

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org



DO NOT REPLY [Bug 48208] allow client certificate with any issuer: server.xml connector attribute "acceptAllCerts"

2011-01-28 Thread bugzilla
https://issues.apache.org/bugzilla/show_bug.cgi?id=48208

Ralf Hauser  changed:

   What|Removed |Added

 Status|RESOLVED|REOPENED
 Resolution|WONTFIX |

--- Comment #2 from Ralf Hauser  2011-01-29 00:34:24 EST ---
Mark, I have to disagree
in the context of CLIENT_CERT, the user still is forced to use a client
certificate. If your policy is of a complexity that the standard
container-provided security features do not match, the application can then
make sure it only provides services to the client-certs provided that conform
with its requirements

-- 
Configure bugmail: https://issues.apache.org/bugzilla/userprefs.cgi?tab=email
--- You are receiving this mail because: ---
You are the assignee for the bug.

-
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org